@@ -1,18 +1,18 @@
 ;(function(){
   var map = {
-  "commitId": "b965116af11fde2db28245622ec9b97ffc2cb90a",
+  "commitId": "24f73aa05624fc209da8f0f2689875aedeb584f0",
   "branchName": "release-client-6.1.x",
-  "buildTime": "2024-06-27 05:56:26 GMT",
-  "buildVersion": "1.0.503",
+  "buildTime": "2024-07-18 10:36:53 GMT",
+  "buildVersion": "1.0.951",
   "css": [
-    "@zoom/client-scheduler/static/css/chunk-vendors.f0f0dc24.css",
-    "@zoom/client-scheduler/static/css/index.1f8c4026.css"
+    "@zoom/client-calendar-desktop/static/css/chunk-vendors.49e8f34d.css",
+    "@zoom/client-calendar-desktop/static/css/app.4022c6dd.css"
   ],
   "js": [
-    "@zoom/client-scheduler/chunk-vendors.4061f47f68bdcc205e6c.js",
-    "@zoom/client-scheduler/index.4061f47f68bdcc205e6c.js"
+    "@zoom/client-calendar-desktop/static/js/chunk-vendors.a7965a68.js",
+    "@zoom/client-calendar-desktop/static/js/app.38f5ad17.js"
   ],
-  "key": "clientSchedulerResource"
+  "key": "@zoom/client-calendar-desktop"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
